"""Tmmluplus group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

TMMLUPLUS_TASKS = {
    "tmmluplus": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_STEM": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_accounting": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_administrative_law": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_advance_chemistry": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_agriculture": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_anti_money_laundering": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_auditing": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_basic_medical_science": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_business_management": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_chinese_language_and_literature": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_clinical_psychology": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_computer_science": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_culinary_skills": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_dentistry": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_economics": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_education": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_education_(profession_level)": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_educational_psychology": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_engineering_math": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_finance_banking": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_financial_analysis": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_fire_science": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_general_principles_of_law": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_geography_of_taiwan": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_human_behavior": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_humanities": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_insurance_studies": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_introduction_to_law": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_jce_humanities": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_junior_chemistry": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_junior_chinese_exam": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_junior_math_exam": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_junior_science_exam": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_junior_social_studies": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_linear_algebra": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_logic_reasoning": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_macroeconomics": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_management_accounting": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_marketing_management": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_mechanical": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_music": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_national_protection": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_nautical_science": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_occupational_therapy_for_psychological_disorders": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_official_document_management": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_optometry": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_organic_chemistry": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_other": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_pharmacology": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_pharmacy": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_physical_education": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_physics": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_politic_science": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_real_estate": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_secondary_physics": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_social_sciences": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_statistics_and_machine_learning": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_taiwanese_hokkien": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_taxation": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_technical": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_three_principles_of_people": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_trade": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_traditional_chinese_medicine_clinical_medicine": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_trust_practice": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_ttqav2": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_tve_chinese_language": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_tve_design": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_tve_mathematics": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_tve_natural_sciences": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_veterinary_pathology": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
    "tmmluplus_veterinary_pharmacology": f"{BASE_IMPORT}tmmluplus:TmmluplusExtractor",
}
