"""Flores group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

# All FLORES task names from flores.py
FLORES_TASKS = {
    "african_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "african_flores_tasks": f"{BASE_IMPORT}flores:FloresExtractor",
    "darija_translation_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "darija_translation_tasks_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_acq_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_acq_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_acq_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aeb_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aeb_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aeb_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr-eng": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr-eng_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr-eng_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr-eng_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aka_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aka_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aka_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_amh_Ethi-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_amh_Ethi-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_amh_Ethi-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ary_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ary_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ary_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_arz_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_arz_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_arz_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bam_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bam_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bam_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ban_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ban_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ban_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bem_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bem_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bem_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_cjk_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_cjk_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_cjk_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dik_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dik_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dik_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dyu_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dyu_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dyu_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng-afr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng-afr_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng-afr_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng-afr_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-acq_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-acq_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-acq_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aeb_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aeb_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aeb_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-afr_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-afr_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-afr_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aka_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aka_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aka_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-amh_Ethi_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-amh_Ethi_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-amh_Ethi_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ary_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ary_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ary_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-arz_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-arz_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-arz_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bam_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bam_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bam_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ban_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ban_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ban_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bem_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bem_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bem_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-cjk_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-cjk_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-cjk_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dik_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dik_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dik_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dyu_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dyu_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dyu_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ewe_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ewe_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ewe_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fon_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fon_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fon_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fra_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fra_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fra_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fuv_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fuv_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fuv_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-gaz_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-gaz_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-gaz_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-hau_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-hau_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-hau_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ibo_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ibo_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ibo_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kab_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kab_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kab_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kam_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kam_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kam_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kbp_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kbp_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kbp_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kea_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kea_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kea_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kik_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kik_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kik_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kin_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kin_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kin_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kmb_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kmb_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kmb_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kon_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kon_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kon_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lin_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lin_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lin_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lua_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lua_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lua_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lug_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lug_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lug_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-luo_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-luo_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-luo_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-mos_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-mos_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-mos_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nso_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nso_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nso_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nus_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nus_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nus_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nya_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nya_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nya_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-plt_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-plt_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-plt_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-run_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-run_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-run_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sag_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sag_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sag_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sna_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sna_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sna_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-som_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-som_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-som_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sot_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sot_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sot_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ssw_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ssw_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ssw_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sun_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sun_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sun_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-swh_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-swh_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-swh_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Tfng_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Tfng_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Tfng_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tir_Ethi_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tir_Ethi_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tir_Ethi_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tsn_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tsn_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tsn_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tso_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tso_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tso_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tum_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tum_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tum_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-twi_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-twi_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-twi_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tzm_Tfng_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tzm_Tfng_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tzm_Tfng_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-umb_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-umb_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-umb_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-wol_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-wol_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-wol_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-xho_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-xho_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-xho_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-yor_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-yor_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-yor_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-zul_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-zul_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-zul_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ewe_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ewe_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ewe_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fon_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fon_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fon_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fra_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fra_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fra_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fuv_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fuv_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fuv_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gaz_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gaz_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gaz_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_hau_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_hau_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_hau_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ibo_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ibo_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ibo_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kab_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kab_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kab_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kam_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kam_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kam_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kbp_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kbp_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kbp_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kea_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kea_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kea_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kik_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kik_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kik_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kin_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kin_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kin_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kmb_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kmb_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kmb_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kon_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kon_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kon_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lin_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lin_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lin_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lua_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lua_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lua_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lug_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lug_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lug_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_luo_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_luo_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_luo_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_mos_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_mos_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_mos_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nso_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nso_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nso_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nus_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nus_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nus_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nya_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nya_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nya_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_plt_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_plt_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_plt_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_run_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_run_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_run_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sag_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sag_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sag_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sna_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sna_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sna_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_som_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_som_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_som_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sot_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sot_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sot_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ssw_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ssw_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ssw_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sun_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sun_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sun_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_swh_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_swh_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_swh_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Tfng-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Tfng-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Tfng-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tir_Ethi-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tir_Ethi-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tir_Ethi-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tsn_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tsn_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tsn_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tso_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tso_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tso_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tum_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tum_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tum_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_twi_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_twi_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_twi_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tzm_Tfng-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tzm_Tfng-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tzm_Tfng-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_umb_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_umb_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_umb_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_wol_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_wol_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_wol_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_xho_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_xho_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_xho_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_yor_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_yor_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_yor_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_zul_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_zul_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_zul_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_all_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_dr_en_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_dr_fr_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_dr_msa_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_en_dr_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_fr_dr_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_msa_dr_flores": f"{BASE_IMPORT}flores:FloresExtractor",
}
